Learn R Programming

lgarch (version 0.4)

coef.mlgarch: Extraction methods for 'mlgarch' objects

Description

Extraction methods for objects of class 'mlgarch' (i.e. the result of estimating a multivariate CCC-log-GARCH model)

Usage

## S3 method for class 'mlgarch':
coef(object, varma = FALSE, ...)
## S3 method for class 'mlgarch':
fitted(object, varma = FALSE, verbose = FALSE, ...)
## S3 method for class 'mlgarch':
logLik(object, varma = FALSE, ...)
## S3 method for class 'mlgarch':
print(x, varma = FALSE, ...)
## S3 method for class 'mlgarch':
residuals(object, varma = FALSE, ...)
## S3 method for class 'mlgarch':
vcov(object, varma = FALSE, ...)

Arguments

object
an object of class 'mlgarch'
x
an object of class 'mlgarch'
verbose
logical. If FALSE (default), then only basic information is returned
varma
logical. If FALSE (default), then information relating to the multivariate CCC-log-GARCH model is returned. If TRUE, then information relating to the VARMA representation is returned
...
additional arguments

Value

  • coef:A numeric vector containing the parameter estimates
  • fitted:A zoo object (a matrix). If verbose = FALSE (default), then the zoo object contains the fitted conditional standard deviations of each equation. If verbose = TRUE, then the zoo object also contains additional information
  • logLik:The value of the log-likelihood (contributions at zeros excluded) at the maximum
  • print:Prints the most important parts of the estimation results
  • residuals:A zoo object (a matrix) with the residuals. If varma = FALSE (default), then the standardised residuals are returned. If varma = TRUE, then the residuals of the VARMA representation is returned
  • vcov:The variance-covariance matrix

Details

Empty

See Also

mlgarch

Examples

Run this code
##simulate 1000 observations from 2-dimensional model w/default parameter values:
set.seed(123)
y <- mlgarchSim(1000)

##estimate a 2-dimensional ccc-log-garch(1,1):
mymod <- mlgarch(y)

##print results:
print(mymod)

##extract ccc-log-garch coefficients:
coef(mymod)

##extract Gaussian log-likelihood (zeros excluded) of the ccc-log-garch model:
logLik(mymod)

##extract Gaussian log-likelihood (zeros excluded) of the varma representation:
logLik(mymod, varma=TRUE)

##extract variance-covariance matrix:
vcov(mymod)

##extract and plot the fitted conditional standard deviations:
sdhat <- fitted(mymod)
plot(sdhat)

##extract and plot standardised residuals:
zhat <- residuals(mymod)
plot(zhat)

Run the code above in your browser using DataLab